__author__ = 'mnowotka'

from chembl_migration_model.models import Activities
from chembl_migration_model.models import Assays
from chembl_migration_model.models import AtcClassification
from chembl_migration_model.models import BindingSites
from chembl_migration_model.models import BioComponentSequences
from chembl_migration_model.models import CellDictionary
from chembl_migration_model.models import ComponentSequences
from chembl_migration_model.models import CompoundProperties
from chembl_migration_model.models import CompoundStructures
from chembl_migration_model.models import Docs
from chembl_migration_model.models import Domains
from chembl_migration_model.models import DrugMechanism
from chembl_migration_model.models import MoleculeDictionary
from chembl_migration_model.models import MoleculeHierarchy
from chembl_migration_model.models import MoleculeSynonyms
from chembl_migration_model.models import ProteinFamilyClassification
from chembl_migration_model.models import ProteinClassification
from chembl_migration_model.models import SiteComponents
from chembl_migration_model.models import Source
from chembl_migration_model.models import TargetComponents
from chembl_migration_model.models import TargetDictionary
from chembl_migration_model.models import Metabolism
from chembl_migration_model.models import MetabolismRefs
from chembl_migration_model.models import DrugIndication
from chembl_migration_model.models import IndicationRefs
from chembl_migration_model.models import GoClassification
from chembl_migration_model.models import ComponentGo
